@@ -32,10 +32,10 @@ int main(int argc, char **argv)
 {
     KAboutData about("dolphin", 0,
                      ki18nc("@title", "Dolphin"),
-                     "1.2",
+                     "1.3",
                      ki18nc("@title", "File Manager"),
                      KAboutData::License_GPL,
-                     ki18nc("@info:credit", "(C) 2006-2008 Peter Penz"));
+                     ki18nc("@info:credit", "(C) 2006-2009 Peter Penz"));
     about.setHomepage("http://dolphin.kde.org");
     about.addAuthor(ki18nc("@info:credit", "Peter Penz"),
                     ki18nc("@info:credit", "Maintainer and developer"),
@@ -61,6 +61,8 @@ int main(int argc, char **argv)
     about.addAuthor(ki18nc("@info:credit", "Michael Austin"),
                     ki18nc("@info:credit", "Documentation"),
                     "tuxedup@users.sourceforge.net");
+    // the .desktop file is not taken into account when launching manually, so
+    // set the icon precautionally:
     about.setProgramIconName("system-file-manager");
 
     KCmdLineArgs::init(argc, argv, &about);
@@ -74,8 +76,6 @@ int main(int argc, char **argv)
     }
 
     DolphinApplication app;
-    // the .desktop file is not taken into account when launching manually, so
-    // set the icon precautionally:
     KGlobal::locale()->insertCatalog("libkonq"); // needed for applications using libkonq
 
     if (app.isSessionRestored()) {
@@ -91,7 +91,7 @@ int main(int argc, char **argv)
             ++n;
         }
     }
-    app.exec();
+    app.exec(); // krazy:exclude=crashy
 
     return 0;
 }
