@@ -268,6 +268,7 @@ KEBApp::KEBApp(
     hsplitter->setOrientation(Qt::Horizontal);
     hsplitter->addWidget(mBookmarkFolderView);
     hsplitter->addWidget(rightSide);
+    hsplitter->setStretchFactor(1,1);
 
     setCentralWidget(hsplitter);
 
@@ -419,8 +420,8 @@ void KEBApp::setActionsEnabled(SelcAbilities sa) {
         }
     }
 
-    for ( QStringList::Iterator it = toEnable.begin();
-            it != toEnable.end(); ++it )
+    for ( QStringList::const_iterator it = toEnable.constBegin();
+            it != toEnable.constEnd(); ++it )
     {
         //kDebug() <<" enabling action "<<(*it);
         coll->action((*it).toAscii().data())->setEnabled(true);
@@ -571,6 +572,10 @@ void KEBApp::updateStatus(const QString &url)
 }
 
 KEBApp::~KEBApp() {
+
+    // Save again, just in case the user expanded/collapsed folders (#131127)
+    CurrentMgr::self()->notifyManagers();
+
     s_topLevel = 0;
     delete m_cmdHistory;
     delete ActionsImpl::self();
