@@ -38,7 +38,6 @@
 #include "konqmisc.h"
 #include "konqsettingsxt.h"
 #include "konqframevisitor.h"
-#include "konqproxystyle.h"
 
 #include <kacceleratormanager.h>
 #include <konqpixmapprovider.h>
@@ -47,76 +46,6 @@
 
 #include <QtGui/QStyle>
 
-//###################################################################
-
-class KonqTabsStyle : public KonqProxyStyle
-{
-public:
-  KonqTabsStyle(QWidget *parent) : KonqProxyStyle(parent) {}
-
-  void drawPrimitive(PrimitiveElement element, const QStyleOption *option, QPainter *painter, const QWidget *widget) const;
-  QRect subElementRect(SubElement element, const QStyleOption *option, const QWidget *widget) const;
-};
-
-void KonqTabsStyle::drawPrimitive(PrimitiveElement element, const QStyleOption *option,
-                                  QPainter *painter, const QWidget *widget) const
-{
-  if (element == PE_FrameTabWidget)
-  {
-    const KonqFrameTabs *tw = static_cast<const KonqFrameTabs*>(widget);
-    const QTabBar *tb = tw->tabBar();
-
-    QStyleOptionTabV2 tab;
-    tab.initFrom(tb);
-    tab.shape = tb->shape();
-    int overlap = style()->pixelMetric(PM_TabBarBaseOverlap, &tab, tb);
-
-    if (overlap <= 0 || tw->isTabBarHidden())
-      return;
-
-    QStyleOptionTabBarBase opt;
-    opt.initFrom(tb);
-
-    opt.selectedTabRect = tb->tabRect(tb->currentIndex());
-    opt.selectedTabRect = QRect(tb->mapToParent(opt.selectedTabRect.topLeft()), opt.selectedTabRect.size());
-    opt.tabBarRect = QRect(tb->mapToParent(tb->rect().topLeft()), tb->size());
-
-    if (tw->tabPosition() == QTabWidget::North)
-      opt.rect = QRect(option->rect.left(), option->rect.top(), option->rect.width(), overlap);
-    else
-      opt.rect = QRect(option->rect.left(), option->rect.bottom() - overlap - 1, option->rect.width(), overlap);
-
-    style()->drawPrimitive(PE_FrameTabBarBase, &opt, painter, tb);
-    return;
-  }
-
-  KonqProxyStyle::drawPrimitive(element, option, painter, widget);
-}
-
-QRect KonqTabsStyle::subElementRect(SubElement element, const QStyleOption *option, const QWidget *widget) const
-{
-  if (element == SE_TabWidgetTabContents)
-  {
-    QRect rect = style()->subElementRect(SE_TabWidgetTabPane, option, widget);
-
-    const KonqFrameTabs *tw = static_cast<const KonqFrameTabs*>(widget);
-    const QTabBar *tb = tw->tabBar();
-
-    QStyleOptionTabV2 tab;
-    tab.initFrom(tb);
-    tab.shape = tb->shape();
-    int overlap = style()->pixelMetric(PM_TabBarBaseOverlap, &tab, tw->tabBar());
-
-    if (overlap <= 0 || tw->isTabBarHidden())
-      return rect;
-
-    return tw->tabPosition() == QTabWidget::North ?
-        rect.adjusted(0, overlap, 0, 0) : rect.adjusted(0, 0, 0, -overlap);
-  }
-
-  return KonqProxyStyle::subElementRect(element, option, widget);
-}
-
 
 //###################################################################
 
@@ -126,22 +55,14 @@ KonqFrameTabs::KonqFrameTabs(QWidget* parent, KonqFrameContainerBase* parentCont
   : KTabWidget(parent),
     m_pPopupMenu(0),
     m_pSubPopupMenuTab(0),
-    m_rightWidget(0), m_leftWidget(0), m_alwaysTabBar(false),
-    m_konqTabsStyle( new KonqTabsStyle( this ) )
+    m_rightWidget(0), m_leftWidget(0), m_alwaysTabBar(false)
 {
   // Set an object name so the widget style can identify this widget.
   setObjectName("kde_konq_tabwidget");
+  setDocumentMode(true);
 
   KAcceleratorManager::setNoAccel(this);
 
-  // Set the widget style to a forwarding proxy style that removes the tabwidget frame,
-  // and draws a tabbar base underneath the tabbar.
-  setStyle(m_konqTabsStyle);
-
-  // The base will be drawn on the frame instead of on the tabbar, so it extends across
-  // the whole widget.
-  tabBar()->setDrawBase(false);
-
   tabBar()->setWhatsThis(i18n( "This bar contains the list of currently open tabs. Click on a tab to make it "
 			  "active. You can also use keyboard shortcuts to "
 			  "navigate through tabs. The text on the tab shows the content "
@@ -160,10 +81,8 @@ KonqFrameTabs::KonqFrameTabs(QWidget* parent, KonqFrameContainerBase* parentCont
 
   m_permanentCloseButtons = KonqSettings::permanentCloseButton();
   if (m_permanentCloseButtons) {
-    setCloseButtonEnabled( true );
+    setTabsClosable( true );
   }
-  else
-    setCloseButtonEnabled( KonqSettings::hoverCloseButton() );
   setTabCloseActivatePrevious( KonqSettings::tabCloseActivatePrevious() );
   if (KonqSettings::tabPosition()=="Bottom")
     setTabPosition( QTabWidget::South );
@@ -172,9 +91,13 @@ KonqFrameTabs::KonqFrameTabs(QWidget* parent, KonqFrameContainerBase* parentCont
            m_pViewManager->mainWindow(), SLOT( slotRemoveTabPopup() ) );
 
   if ( KonqSettings::addTabButton() ) {
-    m_leftWidget = new QToolButton( this );
+    m_leftWidget = new NewTabToolButton( this );
     connect( m_leftWidget, SIGNAL( clicked() ),
              m_pViewManager->mainWindow(), SLOT( slotAddTab() ) );
+    connect( m_leftWidget, SIGNAL( testCanDecode(const QDragMoveEvent *, bool & )),
+             SLOT( slotTestCanDecode(const QDragMoveEvent *, bool & ) ) );
+    connect( m_leftWidget, SIGNAL( receivedDropEvent( QDropEvent * )),
+             SLOT( slotReceivedDropEvent( QDropEvent * ) ) );
     m_leftWidget->setIcon( KIcon( "tab-new" ) );
     m_leftWidget->adjustSize();
     m_leftWidget->setToolTip( i18n("Open a new tab"));
@@ -219,7 +142,6 @@ KonqFrameTabs::~KonqFrameTabs()
   //kDebug(1202) << "KonqFrameTabs::~KonqFrameTabs() " << this << " - " << className();
   qDeleteAll( m_childFrameList );
   m_childFrameList.clear();
-  delete m_konqTabsStyle;
 }
 
 void KonqFrameTabs::saveConfig( KConfigGroup& config, const QString &prefix, const KonqFrameBase::Options &options,
